from setuptools import setup

setup(
    name="tglib",
    version="0.0.1",
    author="Ankit Chaubey",
    author_email="m.ankitchaubey@gmail.com",
    description="A placeholder package for tglib, ready for initial development.",
    long_description="This is the initial release of the tglib package, serving as a foundation for further development.",
    long_description_content_type="text/plain",
    url="https://github.com/ankit-chaubey/tglib",
    packages=["tglib"],
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires=">=3.6",
)
